# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.clients import address_pb2 as v1_dot_clients_dot_address__pb2


class AddressesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddressCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.clients.address.AddressesService/AddressCreate",
            request_serializer=v1_dot_clients_dot_address__pb2.AddressCreateRequest.SerializeToString,
            response_deserializer=v1_dot_clients_dot_address__pb2.AddressCreateResponse.FromString,
        )
        self.AddressUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.clients.address.AddressesService/AddressUpdate",
            request_serializer=v1_dot_clients_dot_address__pb2.AddressUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_clients_dot_address__pb2.AddressUpdateResponse.FromString,
        )
        self.AddressDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.clients.address.AddressesService/AddressDelete",
            request_serializer=v1_dot_clients_dot_address__pb2.AddressDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_clients_dot_address__pb2.AddressDeleteResponse.FromString,
        )


class AddressesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddressCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddressUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddressDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AddressesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "AddressCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AddressCreate,
            request_deserializer=v1_dot_clients_dot_address__pb2.AddressCreateRequest.FromString,
            response_serializer=v1_dot_clients_dot_address__pb2.AddressCreateResponse.SerializeToString,
        ),
        "AddressUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AddressUpdate,
            request_deserializer=v1_dot_clients_dot_address__pb2.AddressUpdateRequest.FromString,
            response_serializer=v1_dot_clients_dot_address__pb2.AddressUpdateResponse.SerializeToString,
        ),
        "AddressDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AddressDelete,
            request_deserializer=v1_dot_clients_dot_address__pb2.AddressDeleteRequest.FromString,
            response_serializer=v1_dot_clients_dot_address__pb2.AddressDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.clients.address.AddressesService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class AddressesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddressCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.clients.address.AddressesService/AddressCreate",
            v1_dot_clients_dot_address__pb2.AddressCreateRequest.SerializeToString,
            v1_dot_clients_dot_address__pb2.AddressCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddressUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.clients.address.AddressesService/AddressUpdate",
            v1_dot_clients_dot_address__pb2.AddressUpdateRequest.SerializeToString,
            v1_dot_clients_dot_address__pb2.AddressUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddressDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.clients.address.AddressesService/AddressDelete",
            v1_dot_clients_dot_address__pb2.AddressDeleteRequest.SerializeToString,
            v1_dot_clients_dot_address__pb2.AddressDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
